render_error_page

Function render_error_page 

pub fn render_error_page(title: &str, message: &str) -> String
Build a static error page by replacing placeholders in the fallback HTML.

Also available as render_error_page for use by other modules that need to produce styled error pages without access to the template environment. Values are HTML-escaped to prevent XSS.